"use strict";(self["webpackChunk_jupyterlab_application_top"]=self["webpackChunk_jupyterlab_application_top"]||[]).push([[8398],{78398:(r,a,e)=>{e.d(a,{diagram:()=>d});var s=e(67863);var t=e(10628);var v=e(46884);var l=e(47925);var p=e(78188);var i=e(25301);var n=e(46103);var u=e(47655);var c=e(92783);var o=e(55750);var b=e(95035);var _=e(29131);var k=e(42418);var w=e(70416);var d={parser:s._$,get db(){return new s.NM},renderer:s.Lh,styles:s.tM,init:(0,w.K2)((r=>{if(!r.class){r.class={}}r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute}),"init")}}}]);