"use strict";(self["webpackChunk_jupyterlab_application_top"]=self["webpackChunk_jupyterlab_application_top"]||[]).push([[2957,5338,100],{5338:(a,e,t)=>{var p;var r=t(86672);if(true){e.H=r.createRoot;p=r.hydrateRoot}else{var o}}}]);