"use strict";(self["webpackChunk_jupyterlab_application_top"]=self["webpackChunk_jupyterlab_application_top"]||[]).push([[7879],{87879:(r,a,e)=>{e.d(a,{diagram:()=>w});var t=e(76901);var v=e(46884);var s=e(47925);var p=e(78188);var i=e(25301);var u=e(46103);var l=e(47655);var n=e(92783);var o=e(55750);var b=e(95035);var k=e(29131);var _=e(42418);var c=e(70416);var w={parser:t.Zk,get db(){return new t.u4(2)},renderer:t.q7,styles:t.tM,init:(0,c.K2)((r=>{if(!r.state){r.state={}}r.state.arrowMarkerAbsolute=r.arrowMarkerAbsolute}),"init")}}}]);